@@ -12,7 +12,7 @@ use AnyEvent::WebSocket::Client;
 use AnyEvent::Future qw(as_future_cb);
 
 use vars qw<$VERSION $magic @CARP_NOT>;
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -100,8 +100,12 @@ Returns a Future that will be resolved in the number of seconds given.
 
 sub sleep( $self, $seconds ) {
 
-    my $res = as_future_cb( sub( $done_cb, $fail_cb ) {
-        AnyEvent->timer( after => $seconds, cb => $done_cb )
+    my $timer;
+    as_future_cb( sub( $done_cb, $fail_cb ) {
+        $timer = AnyEvent->timer( after => $seconds, cb => sub {
+            undef $timer;
+            goto &$done_cb
+        })
     });
 }
 
